@@ -2,9 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import account
-from . import line
-from . import rule
+
+from . import account, line, rule
 from .account import AnalyticMixin
 
 __all__ = [AnalyticMixin]
@@ -14,7 +13,7 @@ def register():
     Pool.register(
         account.Account,
         account.AccountDistribution,
-        account.OpenChartAccountStart,
+        account.AccountContext,
         account.AnalyticAccountEntry,
         line.Line,
         line.Move,
@@ -22,6 +21,5 @@ def register():
         rule.Rule,
         module='analytic_account', type_='model')
     Pool.register(
-        account.OpenChartAccount,
         line.OpenAccount,
         module='analytic_account', type_='wizard')
